Description of functions
========================

Module contents
---------------

.. automodule:: pairef
    :members:
    :undoc-members:
    :show-inheritance:

pairef.launcher module
----------------------

.. automodule:: pairef.launcher
    :members:
    :undoc-members:
    :show-inheritance:

pairef.preparation module
-------------------------

.. automodule:: pairef.preparation
    :members:
    :undoc-members:
    :show-inheritance:

pairef.refinement module
--------------------------------

.. automodule:: pairef.refinement
    :members:
    :undoc-members:
    :show-inheritance:

pairef.graphs module
--------------------

.. automodule:: pairef.graphs
    :members:
    :undoc-members:
    :show-inheritance:

pairef.commons module
---------------------

.. automodule:: pairef.commons
    :members:
    :undoc-members:
    :show-inheritance:

pairef.gui module
-----------------

.. automodule:: pairef.gui
    :members:
    :undoc-members:
    :show-inheritance:

.. pairef.settings module
   ----------------------
    
   .. automodule:: pairef.settings
       :members:
       :undoc-members:
       :show-inheritance:

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
